summaryrefslogtreecommitdiffstats
path: root/lib/widgets/propeditor/multiproperty.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/widgets/propeditor/multiproperty.cpp')
-rw-r--r--lib/widgets/propeditor/multiproperty.cpp54
1 files changed, 27 insertions, 27 deletions
diff --git a/lib/widgets/propeditor/multiproperty.cpp b/lib/widgets/propeditor/multiproperty.cpp
index 17b05797..9c3b04c4 100644
--- a/lib/widgets/propeditor/multiproperty.cpp
+++ b/lib/widgets/propeditor/multiproperty.cpp
@@ -43,50 +43,50 @@ MultiProperty::~MultiProperty()
{
}
-QString MultiProperty::name() const
+TQString MultiProperty::name() const
{
if (list.count() >= 1)
return list.getFirst()->name();
- return QString::null;
+ return TQString::null;
}
int MultiProperty::type() const
{
if (list.count() >= 1)
return list.getFirst()->type();
- return QVariant::Invalid;
+ return TQVariant::Invalid;
}
-QVariant MultiProperty::value() const
+TQVariant MultiProperty::value() const
{
- QVariant value;
+ TQVariant value;
if (list.count() >= 1)
value = list.getFirst()->value();
- QPtrListIterator<Property> it(list);
+ TQPtrListIterator<Property> it(list);
Property *property;
while ((property = it.current()) != 0)
{
if (property->value() != value)
- return QVariant::Invalid;
+ return TQVariant::Invalid;
++it;
}
return value;
}
-QString MultiProperty::description() const
+TQString MultiProperty::description() const
{
- QString description;
+ TQString description;
if (list.count() >= 1)
description = list.getFirst()->description();
- QPtrListIterator<Property> it(list);
+ TQPtrListIterator<Property> it(list);
Property *property;
while ((property = it.current()) != 0)
{
if (property->description() != description)
- return QString::null;
+ return TQString::null;
++it;
}
@@ -99,7 +99,7 @@ bool MultiProperty::readOnly() const
if (list.count() >= 1)
v = list.getFirst()->readOnly();
- QPtrListIterator<Property> it(list);
+ TQPtrListIterator<Property> it(list);
Property *property;
while ((property = it.current()) != 0)
{
@@ -117,7 +117,7 @@ bool MultiProperty::visible() const
if (list.count() >= 1)
v = list.getFirst()->readOnly();
- QPtrListIterator<Property> it(list);
+ TQPtrListIterator<Property> it(list);
Property *property;
while ((property = it.current()) != 0)
{
@@ -129,21 +129,21 @@ bool MultiProperty::visible() const
return v;
}
-QMap<QString, QVariant> MultiProperty::valueList() const
+TQMap<TQString, TQVariant> MultiProperty::valueList() const
{
if (list.count() >= 1)
return list.getFirst()->valueList;
- return QMap<QString, QVariant>();
+ return TQMap<TQString, TQVariant>();
}
-void MultiProperty::setDescription(const QString &description)
+void MultiProperty::setDescription(const TQString &description)
{
Property *property;
for (property = list.first(); property; property = list.next())
property->setDescription(description);
}
/*void MultiProperty::setName(const QString &name)
{
}
@@ -151,7 +151,7 @@ void MultiProperty::setType(int type)
{
}
*/
-void MultiProperty::setValue(const QVariant &value)
+void MultiProperty::setValue(const TQVariant &value)
{
Property *property;
for (property = list.first(); property; property = list.next())
@@ -165,7 +165,7 @@ void MultiProperty::setValue(const QVariant &value)
}
}
-void MultiProperty::setValue(const QVariant &value, bool emitChange)
+void MultiProperty::setValue(const TQVariant &value, bool emitChange)
{
Property *property;
for (property = list.first(); property; property = list.next())
@@ -176,7 +176,7 @@ void MultiProperty::setValue(const QVariant &value, bool emitChange)
}
}
-void MultiProperty::setValueList(const QMap<QString, QVariant> &valueList)
+void MultiProperty::setValueList(const TQMap<TQString, TQVariant> &valueList)
{
Property *property;
for (property = list.first(); property; property = list.next())
@@ -227,13 +227,13 @@ void MultiProperty::removeProperty( MultiProperty *prop)
removeProperty(property);
}
-QVariant MultiProperty::findValueDescription() const
+TQVariant MultiProperty::findValueDescription() const
{
- QVariant val = value();
+ TQVariant val = value();
if (type() != Property::ValueFromList)
return val;
- QMap<QString, QVariant> vl = valueList();
- for (QMap<QString, QVariant>::const_iterator it = vl.begin(); it != vl.end(); ++ it)
+ TQMap<TQString, TQVariant> vl = valueList();
+ for (TQMap<TQString, TQVariant>::const_iterator it = vl.begin(); it != vl.end(); ++ it)
{
if (it.data() == val)
return it.key();
@@ -241,12 +241,12 @@ QVariant MultiProperty::findValueDescription() const
return "";
}
-QVariant MultiProperty::findValueDescription(QVariant val) const
+TQVariant MultiProperty::findValueDescription(TQVariant val) const
{
if (type() != Property::ValueFromList)
return val;
- QMap<QString, QVariant> vl = valueList();
- for (QMap<QString, QVariant>::const_iterator it = vl.begin(); it != vl.end(); ++ it)
+ TQMap<TQString, TQVariant> vl = valueList();
+ for (TQMap<TQString, TQVariant>::const_iterator it = vl.begin(); it != vl.end(); ++ it)
{
if (it.data() == val)
return it.key();
@@ -129,21 +129,21 @@ bool MultiProperty::visible() const
property->setDescription(description);
}
-/*void MultiProperty::setName(const QString &name)
+/*void MultiProperty::setName(const TQString &name)
{
}